<!doctype html>
<html lang="en" ng-app="Ouimeaux">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
    <title>Ouimeaux</title>

    <link rel="stylesheet" href="/static/css/bootstrap.css">
    <link rel="stylesheet" href="/static/css/main.css">

    <script src="/static/lib/angular/angular.js"></script>
    <script src="/static/lib/angular/angular-resource.js"></script>

    <script src="/static/js/app.js"></script>
    <script src="/static/js/controllers.js"></script>
     <script src="/static/js/services.js"></script>
     <script src="/static/js/socket.js"></script>

    <script src="/static/lib/jquery/jquery.min.js"></script>
    <script src="/static/lib/bootstrap/bootstrap.min.js"></script>
    <script src="/static/lib/socket.io/socket.io.js"></script>

</head>
<body>
    <nav class="navbar navbar-default" role="navigation">
        <a class="navbar-brand" href="#">Ouimeaux</a>
    </nav>
    <div id="content" class="container main" ng-view>
    </div>

        <hr>
        <footer id="footer" class="footer">
            <div class="footer-left">
                <span>&copy; 2013 Ian McCracken</span>
            </div>
        </footer>
</body>
</html>