.navbar {
    padding-left: 25px;
}

.header-section {
	padding: 30px 30px;
	background: #222;
	position: absolute;
	top: 50px;
	left: 0px;
	width: 100%;
	margin-left: 0;
	color: #FFF;
}

.main {
	padding-top: 20px;
	min-height: 370px;
}

.footer-left {
    padding-left: 30px;
	float: left;
}

.btn {
    text-align: left;
}

.btn-icon {
    margin-left: 15px;
    margin-right: 15px;
}